/*
 * Network configuration
 * 
 ************************************************************
 * EDIT THIS FILE TO REFLECT YOUR NETWORK CONFIGURATION     *
 * BEFORE RUNNING ANY RTEMS PROGRAMS WHICH USE THE NETWORK! * 
 ************************************************************
 *
 *  $Id: networkconfig.h,v 1.6.4.1 2000/05/09 21:38:58 joel Exp $
 */

#ifndef _RTEMS_NETWORKCONFIG_H_
#define _RTEMS_NETWORKCONFIG_H_

#include <rtems/rtems_bsdnet.h>

/*
 * Define RTEMS_SET_ETHERNET_ADDRESS if you want to specify the
 * Ethernet address here.  If RTEMS_SET_ETHERNET_ADDRESS is not
 * defined the driver will choose an address.
 */

#define RTEMS_SET_ETHERNET_ADDRESS
#if (defined (RTEMS_SET_ETHERNET_ADDRESS))
/* static char ethernet_address[6] = { 0x08, 0x00, 0x3e, 0x12, 0x28, 0xb1 }; */
static char ethernet_address[6] = { 0x00, 0x80, 0x7F, 0x22, 0x61, 0x77 };

#endif

/*
 * Loopback interface
 */
extern void rtems_bsdnet_loopattach(void *);
static struct rtems_bsdnet_ifconfig loopback_config = {
	"lo0",				/* name */
	(int (*)(struct rtems_bsdnet_ifconfig *))rtems_bsdnet_loopattach,	/* attach function */

	NULL,				/* link to next interface */

	"127.0.0.1",			/* IP address */
	"255.0.0.0",			/* IP net mask */
};

/*
 * Default network interface
 */
static struct rtems_bsdnet_ifconfig netdriver_config = {
	RTEMS_BSP_NETWORK_DRIVER_NAME,		/* name */
	RTEMS_BSP_NETWORK_DRIVER_ATTACH,	/* attach function */

	&loopback_config,		/* link to next interface */

	"192.168.2.50",			/* IP address */
	"255.255.255.0",		/* IP net mask */

#if (defined (RTEMS_SET_ETHERNET_ADDRESS))
	ethernet_address,               /* Ethernet hardware address */
#else
	NULL,                           /* Driver supplies hardware address */
#endif
	0				/* Use default driver parameters */
};

/*
 * Network configuration
 */
struct rtems_bsdnet_config rtems_bsdnet_config = {
	&netdriver_config,

	NULL,                   /* no bootp */
	0,			/* Default network task priority */
	0,			/* Default mbuf capacity */
	0,			/* Default mbuf cluster capacity */
	"zverkomrs",		/* Host name */
	"sraz.dkts.co.yu",	/* Domain name */
	"192.168.2.1",		/* Gateway */
	"192.168.2.45",		/* Log host */
	{"192.168.2.30" },	/* Name server(s) */
	{"192.168.2.1" },	/* NTP server(s) */

};

#define CONFIGURE_INIT

#endif /* _RTEMS_NETWORKCONFIG_H_ */
